unfold — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# unfold

ElectronicBandStructure.unfold(transformation_matrix=None, structure=None)

  The method helps unfold the bands. This is done by using the unfolder to find the new kpoint weights. The current weights are then updated

  Parameters:

    - transformation_matrix (np.ndarray, optional) – The transformation matrix to transform the basis. Expected size is (3,3), by default None

    - structure (pyprocar.core.Structure, optional) – The structure of a material, by default None

  Returns:

    None – None